@@ -1,7 +1,8 @@
 #!/usr/bin/python
 # -*- coding: UTF-8 -*-
 import sys
-
+sys.path.append('./')
+sys.path.append('../')
 from comFunction import half_wave_file,set_mac_volume,recovery_mac_volume,str_2_bool,polqa_client_test,match_sig,play_and_rec
 import os
 
